from wiser.gcloud.services.ai_platform.ai_platform_service import AIPlatform

__all__ = ["AIPlatform"]
